/***************************************************************************
 * Copyright 2012 by
 *  + Christian-Albrechts-University of Kiel
 *    + Department of Computer Science
 *      + Software Engineering Group 
 *  and others.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ***************************************************************************/

package kieker.webgui.common;

import kieker.analysis.model.analysisMetaModel.MIPlugin;
import kieker.analysis.model.analysisMetaModel.MIRepository;
import kieker.analysis.model.analysisMetaModel.MIRepositoryConnector;

/**
 * This class is a helper class containing a connection between a filter and a repository.
 * 
 * @author Nils Christian Ehmke
 * @version 1.0
 */
public class ConnectionFilterToRepository {

	/**
	 * The source filter.
	 */
	private MIPlugin source;
	/**
	 * The destination repository.
	 */
	private MIRepository destination;
	/**
	 * The repository port which will be used from the source.
	 */
	private MIRepositoryConnector outputPort;

	/**
	 * Creates a new instance of this class using the given parameters.
	 * 
	 * @param source
	 *            The source filter.
	 * @param destination
	 *            The destination repository.
	 * @param repositoryPort
	 *            The repository port which will be used from the source.
	 */
	public ConnectionFilterToRepository(final MIPlugin source, final MIRepository destination, final MIRepositoryConnector outputPort) {
		this.source = source;
		this.destination = destination;
		this.outputPort = outputPort;
	}

	/**
	 * Delivers the current destination.
	 * 
	 * @return The destination filter.
	 */
	public MIRepository getDestination() {
		return this.destination;
	}

	/**
	 * Sets the new destination.
	 * 
	 * @param destination
	 *            The new destination filter.
	 */
	public void setDestination(final MIRepository destination) {
		this.destination = destination;
	}

	/**
	 * Delivers the current output port.
	 * 
	 * @return The output port which will be used from the source.
	 */
	public MIRepositoryConnector getOutputPort() {
		return this.outputPort;
	}

	/**
	 * Sets the new output port.
	 * 
	 * @param outputPort
	 *            The new output port which will be used from the source.
	 */
	public void setOutputPort(final MIRepositoryConnector outputPort) {
		this.outputPort = outputPort;
	}

	/**
	 * Delivers the source filter.
	 * 
	 * @return The source filter.
	 */
	public MIPlugin getSource() {
		return this.source;
	}

	/**
	 * Sets the source filter to a new value.
	 * 
	 * @param source
	 *            The new source filter.
	 */
	public void setSource(final MIPlugin source) {
		this.source = source;
		// Make sure that the input port is always valid - if necessary even null.
		if (this.source == null) {
			this.outputPort = null;
		}
	}

	/**
	 * Checks whether the current configuration is valid. The configuration is valid if and only if: All four components are not null, the ports exist and are
	 * compatible.
	 * 
	 * @return true if and only if all four components are not null, the ports exist and are compatible.
	 */
	public boolean isValid() {
		if ((this.source == null) || (this.destination == null) || (this.outputPort == null)) {
			return false;
		}
		// TODO: This is currently not necessarily valid
		return true;
	}
}
